"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var cognito_1 = require("./cognito");
var auth_1 = require("./auth");
// When a user comes back from authenticating, the url looks like this:
//   /autosignin#id_token=....
// At this point, there will be no cookies yet. If we would render any page on
// the server now, it would seem as-if the user is not authenticated yet.
//
// We therefore wait until Amplify has set its cookies. It does this
// automatically because the id_token hash is present. Then we redirect the
// user back to the main page. That page can now use SSR as the user will have
// the necessary cookies ready.
function Token(props) {
    var _a = react_1.default.useState(false), triggeredReload = _a[0], setTriggeredReload = _a[1];
    react_1.default.useEffect(function () {
        // only check when #id_token is in the hash, otherwise cookies can't appear
        // anyways
        if (triggeredReload)
            return;
        if (!window.location.hash.includes("id_token=")) {
            props.onToken(null);
            return;
        }
        function refreshOnAuthCookies() {
            if (triggeredReload)
                return;
            var cognitoCookieInfo = cognito_1.getCognitoCookieInfo(document.cookie, process.env.USER_POOL_CLIENT_ID);
            if (cognitoCookieInfo.idToken) {
                setTriggeredReload(true);
                localStorage.setItem(auth_1.AUTH_SYNC_KEY, "login");
                props.onToken(cognitoCookieInfo.idToken);
            }
        }
        refreshOnAuthCookies();
        var interval = setInterval(refreshOnAuthCookies, 100);
        return function () {
            clearInterval(interval);
        };
    }, [triggeredReload, setTriggeredReload]);
    return <react_1.default.Fragment>{props.children}</react_1.default.Fragment>;
}
exports.default = Token;
